@@ -1,27 +1,17 @@
 /*
-    Copyright (c) 2007-2015 Contributors as noted in the AUTHORS file
+    Copyright (c) 2007-2013 Contributors as noted in the AUTHORS file
 
-    This file is part of libzmq, the ZeroMQ core engine in C++.
+    This file is part of 0MQ.
 
-    libzmq is free software; you can redistribute it and/or modify it under
-    the terms of the GNU Lesser General Public License (LGPL) as published
-    by the Free Software Foundation; either version 3 of the License, or
+    0MQ is free software; you can redistribute it and/or modify it under
+    the terms of the GNU Lesser General Public License as published by
+    the Free Software Foundation; either version 3 of the License, or
     (at your option) any later version.
 
-    As a special exception, the Contributors give you permission to link
-    this library with independent modules to produce an executable,
-    regardless of the license terms of these independent modules, and to
-    copy and distribute the resulting executable under terms of your choice,
-    provided that you also meet, for each linked independent module, the
-    terms and conditions of the license of that module. An independent
-    module is a module which is not derived from or based on this library.
-    If you modify this library, you must extend this exception to your
-    version of the library.
-
-    libzmq is distributed in the hope that it will be useful, but WITHOUT
-    ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
-    FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public
-    License for more details.
+    0MQ is distributed in the hope that it will be useful,
+    but WITHOUT ANY WARRANTY; without even the implied warranty of
+    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+    GNU Lesser General Public License for more details.
 
     You should have received a copy of the GNU Lesser General Public License
     along with this program.  If not, see <http://www.gnu.org/licenses/>.
@@ -31,8 +21,8 @@
 #define __TESTUTIL_HPP_INCLUDED__
 
 #include "../include/zmq.h"
-#include "../src/stdint.hpp"
-#include "platform.hpp"
+#include "../include/zmq_utils.h"
+#include "../src/platform.hpp"
 
 //  This defines the settle time used in tests; raise this if we
 //  get test failures on slower systems due to binds/connects not
@@ -44,7 +34,6 @@
 #include <assert.h>
 #include <stdarg.h>
 #include <string>
-#include <string.h>
 
 #if defined _WIN32
 #   if defined _MSC_VER
@@ -90,7 +79,7 @@ bounce (void *server, void *client)
     rc = zmq_getsockopt (server, ZMQ_RCVMORE, &rcvmore, &sz);
     assert (rc == 0);
     assert (!rcvmore);
-
+    
     //  Send two parts back to client
     rc = zmq_send (server, buffer, 32, ZMQ_SNDMORE);
     assert (rc == 32);
@@ -122,17 +111,15 @@ expect_bounce_fail (void *server, void *client)
 {
     const char *content = "12345678ABCDEFGH12345678abcdefgh";
     char buffer [32];
-    int timeout = 250;
 
     //  Send message from client to server
-    int rc = zmq_setsockopt (client, ZMQ_SNDTIMEO, &timeout, sizeof (int));
-    assert (rc == 0);
-    rc = zmq_send (client, content, 32, ZMQ_SNDMORE);
-    assert ((rc == 32) || ((rc == -1) && (errno == EAGAIN)));
+    int rc = zmq_send (client, content, 32, ZMQ_SNDMORE);
+    assert (rc == 32);
     rc = zmq_send (client, content, 32, 0);
-    assert ((rc == 32) || ((rc == -1) && (errno == EAGAIN)));
+    assert (rc == 32);
 
     //  Receive message at server side (should not succeed)
+    int timeout = 150;
     rc = zmq_setsockopt (server, ZMQ_RCVTIMEO, &timeout, sizeof (int));
     assert (rc == 0);
     rc = zmq_recv (server, buffer, 32, 0);
@@ -140,13 +127,10 @@ expect_bounce_fail (void *server, void *client)
     assert (zmq_errno () == EAGAIN);
 
     //  Send message from server to client to test other direction
-    //  If connection failed, send may block, without a timeout
-    rc = zmq_setsockopt (server, ZMQ_SNDTIMEO, &timeout, sizeof (int));
-    assert (rc == 0);
     rc = zmq_send (server, content, 32, ZMQ_SNDMORE);
-    assert (rc == 32 || (rc == -1 && zmq_errno () == EAGAIN));
+    assert (rc == 32);
     rc = zmq_send (server, content, 32, 0);
-    assert (rc == 32 || (rc == -1 && zmq_errno () == EAGAIN));
+    assert (rc == 32);
 
     //  Receive message at client side (should not succeed)
     rc = zmq_setsockopt (client, ZMQ_RCVTIMEO, &timeout, sizeof (int));
@@ -233,7 +217,7 @@ void s_recv_seq (void *socket, ...)
     va_list ap;
     va_start (ap, socket);
     const char * data = va_arg (ap, const char *);
-
+    
     while (true) {
         int rc = zmq_msg_recv (&msg, socket, 0);
         assert (rc != -1);
@@ -259,7 +243,7 @@ void s_recv_seq (void *socket, ...)
 }
 
 
-//  Sets a zero linger period on a socket and closes it.
+// Sets a zero linger period on a socket and closes it.
 void close_zero_linger (void *socket)
 {
     int linger = 0;
@@ -277,14 +261,6 @@ void setup_test_environment()
     _CrtSetReportMode( _CRT_ASSERT, _CRTDBG_MODE_FILE );
     _CrtSetReportFile( _CRT_ASSERT, _CRTDBG_FILE_STDERR );
 #   endif
-#else
-    // abort test after 60 seconds
-    alarm(60);
-#endif
-#if defined __MVS__
-    // z/OS UNIX System Services: Ignore SIGPIPE during test runs, as a
-    // workaround for no SO_NOGSIGPIPE socket option.
-    signal(SIGPIPE, SIG_IGN);
 #endif
 }
 
